ClientTestingUtils

Trait ClientTestingUtils 

pub trait ClientTestingUtils:
    Client
    + Send
    + Sync {
    // Provided method
    fn upload_random_file<'life0, 'life1, 'async_trait>(
        &'life0 self,
        term_spec: &'life1 [(u64, (u64, u64))],
        chunk_size: usize,
    ) -> Pin<Box<dyn Future<Output = Result<RandomFileContents>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait { ... }
}
A trait that adds testing utility functions to the Client interface.

Provided Methods

fn upload_random_file<'life0, 'life1, 'async_trait>( &'life0 self, term_spec: &'life1 [(u64, (u64, u64))], chunk_size: usize, ) -> Pin<Box<dyn Future<Output = Result<RandomFileContents>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Insert a random file into the local CAS.

This function generates a random file with the given term specification. Each term is defined as (xorb_seed, (chunk_start, chunk_end)) where:

  • xorb_seed determines the random data for that XORB
  • chunk_start and chunk_end define the range of chunks to include

Returns a RandomFileContents struct containing all the metadata needed to verify reconstruction and fetching operations.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors