LocalClient

Struct LocalClient 

pub struct LocalClient { /* private fields */ }

Implementations

Source

impl LocalClient

pub async fn temporary(ctx: XetContext) -> Result<Arc<Self>>

Create a local client hosted in a temporary directory for testing. This is an async function to allow use with current-thread tokio runtime.

pub async fn new(ctx: XetContext, path: impl AsRef<Path>) -> Result<Arc<Self>>

Create a local client hosted in a directory. Effectively, this directory is the CAS endpoint and persists across instances of LocalClient.

pub fn set_lifecycle_tag_deletion(&self, on: bool)

Toggle lifecycle-tag deletion mode (see Self::lifecycle_tag_deletion).

Source

impl LocalClient

pub async fn get_reconstruction_v1( &self, file_id: &MerkleHash, bytes_range: Option<FileRange>, ) -> Result<Option<QueryReconstructionResponse>>

V1 reconstruction: returns per-range presigned URLs.

pub async fn get_reconstruction_v2( &self, file_id: &MerkleHash, bytes_range: Option<FileRange>, ) -> Result<Option<QueryReconstructionResponseV2>>

V2 reconstruction: returns per-xorb multi-range fetch descriptors.