pub struct ChunkWindow {
pub dirty_byte_range: [u64; 2],
}Expand description
One chunk-aligned dirty window of a file, returned by GET /v2/file-chunk-hashes/{file_id}.
dirty_byte_range is [start, end) and is expanded outward to the chunk boundaries that
fully contain the requested dirty range, so the client must re-chunk the entire span.
Fields
dirty_byte_range: [u64; 2]Trait Implementations
Sourceimpl Clone for ChunkWindow
impl Clone for ChunkWindow
Sourcefn clone(&self) -> ChunkWindow
fn clone(&self) -> ChunkWindow
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChunkWindow
impl Debug for ChunkWindow
Sourceimpl<'de> Deserialize<'de> for ChunkWindow
impl<'de> Deserialize<'de> for ChunkWindow
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more