pub fn get_cache(
config: &CacheConfig,
) -> Result<Arc<dyn ChunkCache>, ChunkCacheError>Expand description
get_cache attempts to return a cache given the provided config parameter
pub fn get_cache(
config: &CacheConfig,
) -> Result<Arc<dyn ChunkCache>, ChunkCacheError>get_cache attempts to return a cache given the provided config parameter