pub struct CacheRange {
pub offsets: Vec<u32>,
pub data: Vec<u8>,
pub range: ChunkRange,
}Expand description
Return dto for cache gets offsets has 1 more than then number of chunks in the specified range suppose the range is for chunks [2, 5) then offsets may look like: [0, 2000, 4000, 6000] where chunk 2 is made of bytes [0, 2000) chunk 3 [2000, 4000) and chunk 4 is [4000, 6000). It is guaranteed that the first number in offsets is 0 and the last number is data.len()
Fields
offsets: Vec<u32>data: Vec<u8>range: ChunkRangeTrait Implementations