pub struct DiskCache { /* private fields */ }Expand description
DiskCache is a ChunkCache implementor that saves data on the file system
Implementations
Sourceimpl DiskCache
impl DiskCache
pub async fn num_items(&self) -> usize
pub async fn total_bytes(&self) -> u64
Sourcepub fn initialize(config: &CacheConfig) -> Result<Self, ChunkCacheError>
pub fn initialize(config: &CacheConfig) -> Result<Self, ChunkCacheError>
initialize will create a new DiskCache with the capacity and cache root based on the config the cache file system layout is rooted at the provided config.cache_directory and initialize will attempt to load any pre-existing cache state into memory.
an configured size of 0 caused initialization to fail
The cache layout is as follows:
each key (cas hash) in the cache is a directory, containing “cache items” that each provide some range of data.
keys are grouped into subdirectories under the cache rootbased on the first 2 chacters of their file name, which is base64 encoded, leading to at most 64 * 64 directories under the cache root.
cache_root/ ├── [ab]/ │ ├── [key 1 (ab123…)]/ │ │ ├── [range 0-100, file_len, file_hash] │ │ ├── [range 102-300, file_len, file_hash] │ │ └── [range 900-1024, file_len, file_hash] │ ├── [key 2 (ab456…)]/ │ └── [range 0-1020, file_len, file_hash] ├── [cd]/ │ └── [key 3 (cd123…)]/ │ ├── [range 30-31, file_len, file_hash] │ ├── [range 400-402, file_len, file_hash] │ ├── [range 404-405, file_len, file_hash] │ └── [range 679-700, file_len, file_hash]